% script to read in raster fold hinge data and extract fold spacing
% statistics. The script is written for separate processing of each region
% by running specific section (1, 2 or 3) along with following setions for
% all regions. Note that Foldbelt contains two distinct regions with
% structures of different orientations. For statistical analysis each
% region was run seperately (via comment/uncomment to generate spacing data
% (D) and the two resulting vectors were appened before creating the
% historgram and fitting the statistical model.


%% Foldbelt

% load fold hinge image file. Vector hinges sampled at 225 m spacing in
% ArcGIS
FoldIm = imread('FoldBelt_225.tif');

% load background radar image
RadIm = imread('FoldBelt_background.tif');

% change background values from 255 to 1
FoldIm(FoldIm==255) = 1;
FoldIm = ~FoldIm;

% rotate to annalyze NE region
FoldRot = imrotate(FoldIm, 46, 'nearest');
RadRot = imrotate(RadIm, 46, 'nearest');

% rotate to annalyze SW region
% FoldRot = imrotate(FoldIm, 120, 'nearest');
% RadRot = imrotate(RadIm, 120, 'nearest');

% crop to ROI for NE
FoldCrop = FoldRot(551:1050, 551:1250);
RadCrop = RadRot((551*3):(1050*3), (551*3):(1250*3));

% crop to ROI for SW
% FoldCrop = FoldRot(651:1050, 1141:1760);
% RadCrop = RadRot((651*3):(1050*3), (1141*3):(1760*3));

%% Indentor

% load fold hinge image file. Vector hinges sampled at 225 m spacing in
% ArcGIS
FoldIm = imread('Indentor_225.tif');

% load background radar image
RadIm = imread('Indentor_background.tif');

% change background values from 255 to 1
FoldIm(FoldIm==255) = 1;
FoldIm = ~FoldIm;

% rotate to annalyze Indentor
FoldRot = imrotate(FoldIm, 32, 'nearest');
RadRot = imrotate(RadIm, 32, 'nearest');

% crop to ROI for Indentor
FoldCrop = FoldRot(151:1250, 81:850);
RadCrop = RadRot((151*3):(1250*3), (81*3):(850*3));

%% Interior
% load fold hinge image file. Vector hinges sampled at 225 m spacing in
% ArcGIS
FoldIm = imread('Interior_225.tif');

% load background radar image
RadIm = imread('Interior_background.tif');

% change background values from 255 to 1
FoldIm(FoldIm==255) = 1;
FoldIm = ~FoldIm;

% rotate to annalyze Interior
FoldRot = imrotate(FoldIm, 30, 'nearest');
RadRot = imrotate(RadIm, 30, 'nearest');

% crop to ROI for Indentor
FoldCrop = FoldRot(950:2450, 600:2500);
RadCrop = RadRot((950*3):(2450*3), (600*3):(2500*3));

%% General

% open blank figure axes
figure;

% plot radar image with hinges overlying
[ydim, xdim] = size(FoldCrop);
x = (1:xdim)*225;
y = (1:ydim)*225;
subplot(1,2,1)
imagesc(x,y,RadCrop)
axis equal tight
colormap('gray')
hold on
h = image(x,y,FoldCrop);
hold off
set(h, 'AlphaData', FoldCrop)
xlabel('kilometers')
ylabel('kilometers')

% reduce to single pixel thickness
FoldThin = bwmorph(FoldCrop, 'thin', Inf);

% create vector to save results
D = zeros(size(find(FoldThin)));

% initialize counter
c = 1;

% loop over columns
for j = 1:size(FoldThin, 2)
    % find hinge line locations
    Hinges = find(FoldThin(:,j));
    
    % store distances in d vector
    D(c:c + length(Hinges)-2) = diff(Hinges);
    
    % update count
    c = c + length(Hinges)-1;
end

% save only non-zero values and convert to km using cell size
D = D(D>10 & D<444)*225/1000;

%%
% plot histogram
subplot(1,2,2)
bins = 0:1:100;
h = bar(bins(1:end-1)+0.5,histcounts(D,bins)/(length(D)),'histc');
h.FaceColor = [.9 .9 .9];
hold on
xlabel('Fold spacing (km)')
ylabel('Estimated probability')

%%
% Fit data with GMModel using manually-selected initial starting ranges
% starting ranges for each region. Comment/uncomment as needed

% plot GMModel fit
% PckBrk = [19 45 62 73]; % interior
PckBrk = [28 38 50]; % indentor
% PckBrk = [20 26 39]; % Foldbelt

D=sort(D);
%D = D(D<=50);
D = D(D<=95);
ci = ones(size(D,1),1);

for k = 1: length(PckBrk)
ci(D>=PckBrk(k)) = k+1;
end

options = statset('MaxIter',500);
GMModel = fitgmdist(D,length(PckBrk)+1,'Options',options, 'Start', ci);

xgrid = linspace(1.1*min(D),1.1*max(D),200);
pdfgrid = pdf(GMModel,xgrid');
plot(xgrid, pdfgrid,'r')

% output results to screen
GMModel.mu
sqrt(GMModel.Sigma)

axis([0 80 0 0.21])

%% Save results
print('histogram.pdf','-dpdf')

